@@ -1,7 +1,7 @@
 import os
 import shutil
 import logging
-from modeldeploy_proxy_controller.processors.nbprocessor import NotebookProcessor, REQUIREMENTS_TAG, PREPROCESSORS_TAG, POSTPROCESSORS_TAG, FUNCTIONS_TAG, CVAT_INFO_TAG, CVAT_PREPROCESSORS_TAG, CVAT_POSTPROCESSORS_TAG
+from modeldeploy_proxy_controller.processors.nbprocessor import NotebookProcessor, REQUIREMENTS_TAG, PREDICT_TAG, FUNCTIONS_TAG, CVAT_INFO_TAG, CVAT_INVOKE_TAG
 from modeldeploy_proxy_controller.rpc.errors import RPCInternalError
 import requests
 
@@ -9,12 +9,12 @@ def parse_notebook(request, source_notebook_path):
     request.log.debug("parse_notebook with path({})...".format(source_notebook_path))
 
     NEW_LINES = '\n\n';
-    request.log.debug("parse_notebook {}".format(source_notebook_path))
     processor = NotebookProcessor(source_notebook_path)
     blocks = processor.parse_notebook()
     source = ''
 
     requirements = ''
+    request.log.debug("Requirements({})...".format(len(blocks[REQUIREMENTS_TAG])))
     if len(blocks[REQUIREMENTS_TAG]) > 1:
         raise RuntimeError("Requirements tag must be at most 1!")
     elif len(blocks[REQUIREMENTS_TAG]):
@@ -23,21 +23,13 @@ def parse_notebook(request, source_notebook_path):
         else:
             requirements = '{}'.format(blocks[REQUIREMENTS_TAG][0])
 
-    if len(blocks[PREPROCESSORS_TAG]) > 1:
-        raise RuntimeError("Preprocess tag must be at most 1!")
-    elif len(blocks[PREPROCESSORS_TAG]):
+    if len(blocks[PREDICT_TAG]) > 1:
+        raise RuntimeError("Predict tag must be at most 1!")
+    elif len(blocks[PREDICT_TAG]):
         if source:
-            source = '{}{}{}'.format(source, NEW_LINES, blocks[PREPROCESSORS_TAG][0])
+            source = '{}{}{}'.format(source, NEW_LINES, blocks[PREDICT_TAG][0])
         else:
-            source = '{}'.format(blocks[PREPROCESSORS_TAG][0])
-
-    if len(blocks[POSTPROCESSORS_TAG]) > 1:
-        raise RuntimeError("Postprocess tag must be at most 1!")
-    elif len(blocks[POSTPROCESSORS_TAG]):
-        if source:
-            source = '{}{}{}'.format(source, NEW_LINES, blocks[POSTPROCESSORS_TAG][0])
-        else:
-            source = '{}'.format(blocks[POSTPROCESSORS_TAG][0])
+            source = '{}'.format(blocks[PREDICT_TAG][0])
 
     if len(blocks[CVAT_INFO_TAG]) > 1:
         raise RuntimeError("CVAT info tag must be at most 1!")
@@ -47,21 +39,13 @@ def parse_notebook(request, source_notebook_path):
         else:
             source = '{}'.format(blocks[CVAT_INFO_TAG][0])
 
-    if len(blocks[CVAT_PREPROCESSORS_TAG]) > 1:
-        raise RuntimeError("CVAT preprocess tag must be at most 1!")
-    elif len(blocks[CVAT_PREPROCESSORS_TAG]):
+    if len(blocks[CVAT_INVOKE_TAG]) > 1:
+        raise RuntimeError("CVAT invoke tag must be at most 1!")
+    elif len(blocks[CVAT_INVOKE_TAG]):
         if source:
-            source = '{}{}{}'.format(source, NEW_LINES, blocks[CVAT_PREPROCESSORS_TAG][0])
+            source = '{}{}{}'.format(source, NEW_LINES, blocks[CVAT_INVOKE_TAG][0])
         else:
-            source = '{}'.format(blocks[CVAT_PREPROCESSORS_TAG][0])
-
-    if len(blocks[CVAT_POSTPROCESSORS_TAG]) > 1:
-        raise RuntimeError("CVAT postprocess tag must be at most 1!")
-    elif len(blocks[CVAT_POSTPROCESSORS_TAG]):
-        if source:
-            source = '{}{}{}'.format(source, NEW_LINES, blocks[CVAT_POSTPROCESSORS_TAG][0])
-        else:
-            source = '{}'.format(blocks[CVAT_POSTPROCESSORS_TAG][0])
+            source = '{}'.format(blocks[CVAT_INVOKE_TAG][0])
 
     if len(blocks[FUNCTIONS_TAG]):
         for function in blocks[FUNCTIONS_TAG]:
@@ -71,6 +55,7 @@ def parse_notebook(request, source_notebook_path):
                 source = '{}'.format(function)
 
     request.log.debug("Write contents...")
+    request.log.debug(requirements)
     requirements_path = processor.write_requirements_file(requirements);
     transformer_path = processor.write_transformer_python(source);
 
